@@ -14,6 +14,7 @@ from .xmlchemy import (
     BaseOxmlElement, OneAndOnlyOne, OptionalAttribute, RequiredAttribute,
     ZeroOrOne
 )
+from ..shared import lazyproperty, Emu
 
 
 class CT_Blip(BaseOxmlElement):
@@ -126,6 +127,22 @@ class CT_Picture(BaseOxmlElement):
     blipFill = OneAndOnlyOne('pic:blipFill')
     spPr = OneAndOnlyOne('pic:spPr')
 
+    @lazyproperty
+    def parent(self):
+        return self.getparent().getparent().getparent()
+
+    @lazyproperty
+    def parent_off_x(self):
+        if hasattr(self.parent, 'positionH') and self.parent.positionH is not None:
+            return self.parent.positionH.value
+        return Emu(0)
+
+    @lazyproperty
+    def parent_off_y(self):
+        if hasattr(self.parent, 'positionV') and self.parent.positionV is not None:
+            return self.parent.positionV.value
+        return Emu(0)
+
     @classmethod
     def new(cls, pic_id, filename, rId, cx, cy):
         """
