@@ -89,6 +89,13 @@ class CT_PositionV(BaseOxmlElement):
         return Emu(self.posOffset.text)
 
 
+class CT_WpsTxbx(BaseOxmlElement):
+    """
+    Used for ``wps:txbx``
+    """
+    txbxContent = OneAndOnlyOne('w:txbxContent')
+
+
 class CT_AC_Fallback(BaseOxmlElement):
     """
     Used for ``mc:Fallback``
@@ -117,12 +124,16 @@ class GroupBaseOxmlElement(BaseOxmlElement):
 
     @lazyproperty
     def width_unit(self):
+        if not self.coord_size:
+            return 12700
         if self.coord_origin:
             return self.coord_origin[0] + self.coord_size[0]
         return self.coord_size[0]
 
     @lazyproperty
     def height_unit(self):
+        if not self.coord_size:
+            return 12700
         if self.coord_origin:
             return self.coord_origin[1] + self.coord_size[1]
         return self.coord_size[1]
